[llvm-commits] [vector_llvm] CVS: llvm/include/llvm/Bytecode/BytecodeHandler.h
Robert Bocchino
bocchino at cs.uiuc.edu
Tue Oct 18 12:22:21 PDT 2005
Changes in directory llvm/include/llvm/Bytecode:
BytecodeHandler.h updated: 1.9 -> 1.9.4.1
---
Log message:
Initial commit of Vector LLVM.
---
Diffs of the changes: (+5 -5)
BytecodeHandler.h | 10 +++++-----
1 files changed, 5 insertions(+), 5 deletions(-)
Index: llvm/include/llvm/Bytecode/BytecodeHandler.h
diff -u llvm/include/llvm/Bytecode/BytecodeHandler.h:1.9 llvm/include/llvm/Bytecode/BytecodeHandler.h:1.9.4.1
--- llvm/include/llvm/Bytecode/BytecodeHandler.h:1.9 Thu May 5 17:31:18 2005
+++ llvm/include/llvm/Bytecode/BytecodeHandler.h Tue Oct 18 14:21:56 2005
@@ -23,7 +23,7 @@
class ArrayType;
class StructType;
class PointerType;
-class PackedType;
+class FixedVectorType;
class ConstantArray;
class Module;
@@ -267,10 +267,10 @@
Constant* Val ///< The constant value
) {}
- /// @brief Handle a constant packed
- virtual void handleConstantPacked(
- const PackedType* PT, ///< Type of the array
- std::vector<Constant*>& ElementSlots,///< Slot nums for packed values
+ /// @brief Handle a constant fixed vector
+ virtual void handleConstantVector(
+ const FixedVectorType* PT, ///< Type of the fixed vector
+ std::vector<Constant*>& ElementSlots,///< Slot nums for fixed vector values
unsigned TypeSlot, ///< Slot # of type
Constant* Val ///< The constant value
) {}
More information about the llvm-commits
mailing list